<?php
namespace Teknisa\CADPED\Controllers;

use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO;
use Geral\Logic\ParceiroNegocio;
use Teknisa\CADPED\Controllers\TeknisaCrud;
use Teknisa\CADPED\Services\Ger00700ClienteService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;


class Ger00700ClienteController extends TeknisaCrud
{
    protected $dataSourceName;
    protected $connection;

    public function __construct($crudService, $parameterBag, Ger00700ClienteService $service, $entityManager) {
        $this->service    = $service;
        parent::__construct($crudService, $parameterBag);
        $this->connection = $entityManager->getConnection();
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $dataSource = substr($request->getRoutePath(), 1, strlen($request->getRoutePath()));
        $this->dataSourceName = $dataSource;
        parent::find($request, $response);
    }

    public function save(DTO\Request $request, DTO\Response $response) {
        $dataSource = substr($request->getRoutePath(), 1, strlen($request->getRoutePath()) - 6);
        $this->dataSourceName = $dataSource;
        parent::save($request, $response);
    }
    public function saveParams(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = 'cliente';
        parent::save($request, $response);
        // var_dump($response);
    }

    public function delete(DTO\Request $request, DTO\Response $response) {
        $dataSource = substr($request->getRoutePath(), 1, strlen($request->getRoutePath()) - 8);
        $this->dataSourceName = $dataSource;
        parent::delete($request, $response);
    }

    public function deleteFormaPagamento(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $this->service->deleteFormaPagamento($request->getRow());
        }
        catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 500));
        }
    }
    
    public function salvarObservacaoCliente(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = 'observclie_operador';
        $row = $request->getRow();
        $row['DSOBSERVCLIE'] = isset($row['DSOBSERVCLIE'])?bin2hex($row['DSOBSERVCLIE']):null;
        parent::save($request, $response);
    }
    /*
        Faz a busca em todas as observações por cliente.
        Caso o campo não se eocntre no formato html, realiza a
        conversão do campo de RTF (Formato que é utilizado no Delphi) para
        HTML (Formato entendido pelo mobile)
    */
    public function findObservacaoCliente(DTO\Request $request, DTO\Response $response) {
        $dataSource = substr($request->getRoutePath(), 1, strlen($request->getRoutePath()));
        $this->dataSourceName = $dataSource;
        parent::find($request, $response);
        
        $data  = $response->getDataSets();
        $rows = $data[0]->getRows();
        
        $rows  = $this->service->rtf2Html($rows);
        
        $dataSet = new DataSet("observclie_operador", $rows);
        $response->setDataSets(array($dataSet));
    }
    
    public function salvarPrazos(DTO\Request\DataSet $request, DTO\Response $response)
    {
        $rows = $request->getDataSet();
        $rows = $rows->getRows();
        
        try{
            $this->connection->beginTransaction();
            
            $this ->service->deletaPrazo($rows);
            $this->service->insertPrazo($rows);
            
            $this->connection->commit();
        } catch (\Exception $e) {
             $this->entityManager->rollback();
             throw $e;
        }

    }
    
    public function deletarPrazos(DTO\Request\Row $request, DTO\Response $response) {
        $rows = array();
        $rows[0] = $request->getRow();
        $this->service->deletaPrazo($rows);
    }
    
    
    
    public function salvarCompacArq(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $this->service->salvarCompacArq($row);
    }
    
}